==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/item/compat/CompatBlockItem.java <==
package net.tlotd.item.compat;

import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2960;

public class CompatBlockItem extends class_1747 {

    private final String compat;

    public CompatBlockItem(class_2248 block, class_1793 settings, String compat) {
        super(block, settings);
        this.compat = compat;
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 MODS_FONT_ID = new class_2960("tlotd", "mods");

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        if (context.method_47370()){
            class_2583 style = this.method_7848().method_10866();
            if (compat.contains("aet")) {
                tooltip.add(class_2561.method_43470("\uE008 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.aether.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("tlf")) {
                tooltip.add(class_2561.method_43470("\uE009 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.twilightforest.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("cre")) {
                tooltip.add(class_2561.method_43470("\uE00A ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.create.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("atm")) {
                tooltip.add(class_2561.method_43470("\uE00B ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.allthemodium.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("axc")) {
                tooltip.add(class_2561.method_43470("\uE00C ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.alexscaves.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("bop")) {
                tooltip.add(class_2561.method_43470("\uE00D ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.biomesoplenty.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("qrk")) {
                tooltip.add(class_2561.method_43470("\uE00E ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.quark.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("thr")) {
                tooltip.add(class_2561.method_43470("\uE00F ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.thermal.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("spr")) {
                tooltip.add(class_2561.method_43470("\uE010 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.spore.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("skh")) {
                tooltip.add(class_2561.method_43470("\uE011 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.sculkhorde.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("wsm")) {
                tooltip.add(class_2561.method_43470("\uE012 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.witherstormmod.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            super.method_7851(stack, world, tooltip, context);
        }
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/item/compat/CompatBlockItem.java <==
package net.tlotd.item.compat;

import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2960;

public class CompatBlockItem extends class_1747 {

    private final String compat;

    public CompatBlockItem(class_2248 block, class_1793 settings, String compat) {
        super(block, settings);
        this.compat = compat;
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 MODS_FONT_ID = new class_2960("tlotd", "mods");

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        if (context.method_47370()){
            class_2583 style = this.method_7848().method_10866();
            if (compat.contains("aet")) {
                tooltip.add(class_2561.method_43470("\uE008 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.aether.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("tlf")) {
                tooltip.add(class_2561.method_43470("\uE009 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.twilightforest.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("cre")) {
                tooltip.add(class_2561.method_43470("\uE00A ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.create.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("atm")) {
                tooltip.add(class_2561.method_43470("\uE00B ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.allthemodium.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("axc")) {
                tooltip.add(class_2561.method_43470("\uE00C ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.alexscaves.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("bop")) {
                tooltip.add(class_2561.method_43470("\uE00D ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.biomesoplenty.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("qrk")) {
                tooltip.add(class_2561.method_43470("\uE00E ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.quark.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("thr")) {
                tooltip.add(class_2561.method_43470("\uE00F ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.thermal.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("spr")) {
                tooltip.add(class_2561.method_43470("\uE010 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.spore.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("skh")) {
                tooltip.add(class_2561.method_43470("\uE011 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.sculkhorde.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("wsm")) {
                tooltip.add(class_2561.method_43470("\uE012 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.witherstormmod.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            if (compat.contains("ast")) {
                tooltip.add(class_2561.method_43470("\uE015 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.ad_astra.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            }
            super.method_7851(stack, world, tooltip, context);
        }
    }
}
